pub struct ResolveAllResponse {
pub flags: HashMap<String, AnyFlag>,
pub metadata: Option<Struct>,
}Expand description
Response body for bulk flag evaluation, used by the ResolveAll rpc.
Fields
flags: HashMap<String, AnyFlag>Object structure describing the evaluated flags for the provided context.
metadata: Option<Struct>Metadata for the bulk evaluation